@@ -7,7 +7,7 @@ use v5.26;
 use warnings;
 use Object::Pad 0.800;
 
-package Device::Chip::Adapter::BusPirate 0.24;
+package Device::Chip::Adapter::BusPirate 0.25;
 class Device::Chip::Adapter::BusPirate;
 
 # Can't isa Device::Chip::Adapter because it doesn't have a 'new'
@@ -238,7 +238,10 @@ async method read_gpios ( $gpios )
 }
 
 class
-   Device::Chip::Adapter::BusPirate::_SPI :isa(Device::Chip::Adapter::BusPirate::_base);
+   Device::Chip::Adapter::BusPirate::_SPI
+   :isa(Device::Chip::Adapter::BusPirate::_base)
+   :does(Device::Chip::ProtocolBase::SPI)
+   ;
 
 use Carp;
 
@@ -263,11 +266,6 @@ method configure ( %args )
     );
 }
 
-method readwrite ( $data )
-{
-   $self->mode->writeread_cs( $data );
-}
-
 method readwrite_no_ss ( $data )
 {
    $self->mode->writeread( $data );
